@@ -1,4 +1,4 @@
-/* Lasem - SVG and Mathml library
+/* Lasem
  *
  * Copyright © 2009 Emmanuel Pacaud
  *
@@ -194,17 +194,19 @@ lsm_svg_view_add_gradient_color_stop (LsmSvgView *view, double offset)
 					   style->stop_opacity->value * view->pattern_data->opacity);
 }
 
-void
+gboolean
 lsm_svg_view_set_gradient_properties (LsmSvgView *view,
 				      LsmSvgSpreadMethod method,
 				      LsmSvgPatternUnits units,
 				      const LsmSvgMatrix *gradient_matrix)
 {
 	cairo_matrix_t matrix;
+	cairo_matrix_t inv_matrix;
+	cairo_status_t status;
 
-	g_return_if_fail (LSM_IS_SVG_VIEW (view));
-	g_return_if_fail (view->pattern_data != NULL);
-	g_return_if_fail (view->pattern_data->pattern != NULL);
+	g_return_val_if_fail (LSM_IS_SVG_VIEW (view), FALSE);
+	g_return_val_if_fail (view->pattern_data != NULL, FALSE);
+	g_return_val_if_fail (view->pattern_data->pattern != NULL, FALSE);
 
 	switch (method) {
 		case LSM_SVG_SPREAD_METHOD_REFLECT:
@@ -238,7 +240,17 @@ lsm_svg_view_set_gradient_properties (LsmSvgView *view,
 
 	}
 
+	inv_matrix = matrix;
+	status = cairo_matrix_invert (&inv_matrix);
+
+	if (status != CAIRO_STATUS_SUCCESS) {
+		lsm_debug_render ("[LsmSvgView::set_gradient_properties] Not invertible matrix");
+		return FALSE;
+	}
+
 	cairo_pattern_set_matrix (view->pattern_data->pattern, &matrix);
+
+	return TRUE;
 }
 
 gboolean
@@ -250,6 +262,8 @@ lsm_svg_view_create_surface_pattern (LsmSvgView *view,
 	cairo_surface_t *surface;
 	cairo_pattern_t *pattern;
 	cairo_matrix_t matrix;
+	cairo_matrix_t inv_matrix;
+	cairo_status_t status;
 	double x1, y1, x2, y2;
 	double device_width, device_height;
 	double x_scale, y_scale;
@@ -320,6 +334,14 @@ lsm_svg_view_create_surface_pattern (LsmSvgView *view,
 		cairo_matrix_translate (&matrix, -viewport->x, -viewport->y);
 	}
 
+	inv_matrix = matrix;
+	status = cairo_matrix_invert (&inv_matrix);
+
+	if (status != CAIRO_STATUS_SUCCESS) {
+		lsm_debug_render ("[LsmSvgView::create_surface_pattern] Not invertible matrix");
+		return FALSE;
+	}
+
 	cairo_pattern_set_matrix (view->pattern_data->pattern, &matrix);
 	cairo_pattern_set_extend (view->pattern_data->pattern, CAIRO_EXTEND_REPEAT);
 
@@ -1656,13 +1678,15 @@ lsm_svg_view_viewbox_to_viewport (LsmSvgView *view, const LsmBox *viewport, cons
 		*y = *y * y_scale + y_offset;
 }
 
-void
+gboolean
 lsm_svg_view_push_matrix (LsmSvgView *view, const LsmSvgMatrix *matrix)
 {
 	cairo_matrix_t cr_matrix;
+	cairo_matrix_t cr_inv_matrix;
 	cairo_matrix_t *ctm;
+	cairo_status_t status;
 
-	g_return_if_fail (LSM_IS_SVG_VIEW (view));
+	g_return_val_if_fail (LSM_IS_SVG_VIEW (view), FALSE);
 
 	ctm = g_new (cairo_matrix_t, 1);
 	cairo_get_matrix (view->dom_view.cairo, ctm);
@@ -1673,6 +1697,14 @@ lsm_svg_view_push_matrix (LsmSvgView *view, const LsmSvgMatrix *matrix)
 		   matrix->a, matrix->b, matrix->c, matrix->d, matrix->e, matrix->f);
 
 	cairo_matrix_init (&cr_matrix, matrix->a, matrix->b, matrix->c, matrix->d, matrix->e, matrix->f);
+	cr_inv_matrix = cr_matrix;
+	status = cairo_matrix_invert (&cr_inv_matrix) == CAIRO_STATUS_SUCCESS;
+
+	if (status == CAIRO_STATUS_SUCCESS) {
+		lsm_debug_render ("[LsmSvgView::push_matrix] Not invertible matrix");
+       		return FALSE;
+	}
+
 	cairo_transform (view->dom_view.cairo, &cr_matrix);
 
 	{
@@ -1683,6 +1715,8 @@ lsm_svg_view_push_matrix (LsmSvgView *view, const LsmSvgMatrix *matrix)
 			   current_ctm.xx, current_ctm.xy, current_ctm.yx, current_ctm.yy,
 			   current_ctm.x0, current_ctm.y0);
 	}
+
+	return TRUE;
 }
 
 void
